﻿--------------------------------------------------------------------------------
--  iTip
--
--  Description: Adds useful information to item tooltips.
--  Author: CHiLLZ <chillz@gmail.com>
--  License: Copyright 2006-2015, all rights reserved.
--  Website: http://www.curse.com/addons/wow/itip
--
--------------------------------------------------------------------------------

ITIP = {};
ITIP.version = 1.51;
ITIP.minimum_version = 1.5;
ITIP.debug = false;
ITIP.prefix = "|cFF33CCFF[iTip]|cFFFFFFFF  ";

--------------------------------------------------------------------------------
--  BOOTSTRAP
--------------------------------------------------------------------------------

ITIP.Load = function( self )
	self:RegisterEvent("ADDON_LOADED");
	
	SLASH_iTip1 = "/itip";
	SlashCmdList["iTip"] = ITIP.Command;
end

ITIP.Event = function( self, event, ... )
	local arg = ...;
	
	if (event == "ADDON_LOADED") and (arg == "iTip") then
		self:UnregisterEvent("ADDON_LOADED");
		ITIP.Startup();
	end
end

--------------------------------------------------------------------------------
--  CORE FUNCTIONS
--------------------------------------------------------------------------------

ITIP.Toggle = function( value )
	local new_val;
	
	if value then
		new_val = false;
	else
		new_val = true;
	end
	
	return new_val;
end

ITIP.BoolToString = function( value )
	local readable;
	
	if (value == nil)then
		readable = nil;
	elseif value then
		readable = {"TRUE","ON","ENABLED"};
	else
		readable = {"FALSE","OFF","DISABLED"};
	end
	
	return readable;
end

ITIP.Startup = function()
	-- initialize saved variables
	if (ITIP_CONFIG.version == nil) or (ITIP_CONFIG.version < ITIP.minimum_version) then
		ITIP_CONFIG = {};
		ITIP_CONFIG.version = ITIP.version;
		ITIP_CONFIG.enabled = true;
		ITIP_CONFIG.filter = true;
	end
	
	if ITIP.debug then
		if ITIP_CONFIG.enabled then print(ITIP.prefix.."Enabled = TRUE"); else print(ITIP.prefix.."Enabled = FALSE"); end
	end
	
	-- localization
	local lang = GetLocale();
	-- validate locale
	if (ITIP_TRANSLATIONS[lang] == nil) or (#ITIP_TRANSLATIONS[lang] < 3) then
		ITIP.labels = ITIP.TRANSLATIONS["enUS"];
	else
		ITIP.labels = ITIP_TRANSLATIONS[lang];
	end
	
	-- startup message
	local message;
	if (ITIP.version > ITIP_CONFIG.version) then
		ITIP_CONFIG.version = ITIP.version;
		message = "updated to v"..tostring(ITIP.version).."!";
	else
		message = "v"..tostring(ITIP.version).." loaded.";
	end
	
	local current_state = ITIP.BoolToString(ITIP_CONFIG.enabled);
	DEFAULT_CHAT_FRAME:AddMessage("|cFF33CCFFiTip "..message.."|cFFFFFFFF  Type /itip for help.  (Currently "..current_state[3]..")");
end

ITIP.Hook = function( tooltip )
	-- debugging output
	if ITIP.debug then print(ITIP.prefix.."Hook function called for "..tooltip:GetName().." "..tooltip:GetItem()); end
	
	if ITIP_CONFIG.enabled then
		local itemName, itemLink = tooltip:GetItem();
		
		-- make sure this is actually an item
		if itemLink then
			-- extract the item ID from the link
			local prefix, itemID = strsplit(':', itemLink);
			
			-- get all the rest of the item info
			local sName, sLink, iQuality, iLevel, iMinLevel, sType, sSubType, iStackSize, sEquipLoc = GetItemInfo(itemID);
			
			------------------------------------------------------------
			-- INSERT TOOLTIP LINES
			------------------------------------------------------------
			if sType then
				-- ITEM CATEGORY
				if (strlen(sEquipLoc) == 0) or (ITIP_CONFIG.filter == false) then 
					tooltip:AddLine("\n"..sType.." ("..sSubType..")");
				end
				
				-- STACK SIZE
				if (iStackSize > 1) then tooltip:AddLine(ITIP.labels[2]..":  "..iStackSize, 1,1,1); end
				
				-- ITEM LEVEL
				if (strlen(sEquipLoc) == 0) then tooltip:AddLine(ITIP.labels[1]..":  "..iLevel, 1,1,1); end
				
				-- ITEM ID
				tooltip:AddLine(ITIP.labels[3]..":  "..itemID, 1,1,1);
			
			elseif ITIP.debug then
				-- the item query failed
				print(ITIP.prefix.."Error: Bad result from GetItemInfo()");
			end
		end
	end
end
-- register hook
GameTooltip:HookScript("OnTooltipSetItem", ITIP.Hook);

--------------------------------------------------------------------------------
--  COMMAND INTERFACE
--------------------------------------------------------------------------------

ITIP.Command = function( input, editbox )
	-- parse input
	local cmd, arg, val = strsplit(' ', input);
	cmd = strlower(cmd);
	
	-- actions
	if (string.len(cmd) == 0) or (cmd == "help") then
		ITIP.Help();
	elseif (cmd == "show") then
		ITIP.Show();
	elseif (cmd == "filter") then
		ITIP.Filter();
	else
		ITIP.Help(true);
	end
end

ITIP.Help = function( err )
	local output;
	local current_state = ITIP.BoolToString(ITIP_CONFIG.enabled);
	
	if err then
		output = "Unknown command. For more info type:  /itip help";
	else
		output = "Available commands:\n"..
		"|cFFFFFF00/itip help |r\n"..
		"    Shows this help info.\n"..
		"|cFFFFFF00/itip show |r\n"..
		"    Turns the entire addon on/off.  [Currently: "..current_state[1].."]\n"..
		"|cFFFFFF00/itip filter |r\n"..
		"    Toggle showing the item category for equipment.";
	end
	
	DEFAULT_CHAT_FRAME:AddMessage(ITIP.prefix..output);
end

ITIP.Show = function( input, editbox )
	-- change config setting
	ITIP_CONFIG.enabled = ITIP.Toggle(ITIP_CONFIG.enabled);
	
	-- text output
	local current_state = ITIP.BoolToString(ITIP_CONFIG.enabled);
	DEFAULT_CHAT_FRAME:AddMessage(ITIP.prefix.."Tooltip enhancement "..current_state[2]..".");
end

ITIP.Filter = function()
	local message;
	
	-- change config setting
	ITIP_CONFIG.filter = ITIP.Toggle(ITIP_CONFIG.filter);
	
	-- text output
	if (ITIP_CONFIG.filter == true) then
		message = "Item category of equipment will NOT be displayed. (default)";
	else
		message = "Now showing the item category of equipment.";
	end
	
	DEFAULT_CHAT_FRAME:AddMessage(ITIP.prefix..message);
end

